@@ -238,7 +238,7 @@ class PSSMdevice(ABC):
     #endregion
 
     #region methods
-    def _set_screen(self, ScreenInstance : "PSSMScreen"):
+    def _set_screen(self):
         """
         This method sets the screen property. Can be used to set additional settings, or register shorthand functions.
         ScreenInstance is the running PSSMScreen instance.
@@ -246,10 +246,8 @@ class PSSMdevice(ABC):
         #When overwriting this, calling the super() function first is adviced
         #Also backlight shorthands are registered by the screen itself, so those do not need to be done.
         #Setting the attribute will in the furure likely be handled by the screen itself
-        if hasattr(self,"_Screen"):
-            raise AttributeError("A device's screen instance can only be set once.")
-        self._Screen = ScreenInstance
-        self._updateCondition = asyncio.Condition(loop=self._Screen.mainLoop)
+
+        return
 
     def has_feature(self, feature: str) -> bool:
         """Returns true if the device has this feature (i.e. is it true in device.Features)
@@ -334,11 +332,6 @@ class PSSMdevice(ABC):
         """
         pass
 
-    @abstractmethod
-    def close_interaction_handler(self):
-        "Stops the interaction handler"
-        pass
-
     def power_off(self,*args):
         "Powers off the device. Does nothing if the device does not support the power feature."
         _LOGGER.warning("Device does not support power off. Saving Settings though.")
@@ -398,8 +391,8 @@ class Network(ABC):
         return self._connected
 
     @property
-    def signal(self) -> int:
-        "Wifi signal percentage, from 0-100"
+    def signal(self) -> Optional[int]:
+        "Wifi signal percentage, from 0-100, or None if unavailable."
         return self._signal
 
     @property
@@ -533,9 +526,10 @@ class Backlight(ABC):
 
         self._default_seconds_on : Union[int,float] = s
         "Default time on in seconds. Set automatically when setting default_time_on"
-
-        asyncio.create_task(
-            self.notify_condition())
+        with suppress(RuntimeError):
+            loop = asyncio.get_running_loop()
+            loop.create_task(
+                self.notify_condition())
     #endregion
 
     async def notify_condition(self):
